"""
Metadata module for Klovis.

Handles enrichment of data with metadata such as tags, Q/A pairs, or embeddings.
"""

from .metadata_generator import MetadataGenerator

__all__ = ["MetadataGenerator"]
